-- Ensure you have NativeUI included
-- NativeUI Initialization
local MenuPool = NativeUI.CreatePool()
local mainMenu = NativeUI.CreateMenu("Underglow Menu", "Select your desired option")
MenuPool:Add(mainMenu)

local vehicleColors = {
    {name = "Red", r = 255, g = 0, b = 0},
    {name = "Green", r = 0, g = 255, b = 0},
    {name = "Blue", r = 0, g = 0, b = 255},
    {name = "Yellow", r = 255, g = 255, b = 0},
    {name = "Purple", r = 128, g = 0, b = 128},
    {name = "Cyan", r = 0, g = 255, b = 255},
    {name = "White", r = 255, g = 255, b = 255}
}

local customColor = {r = 255, g = 255, b = 255}
local rgbActive = false

-- Function to toggle the vehicle's underglow
local function toggleUnderglow()
    local playerPed = PlayerPedId()
    if IsPedInAnyVehicle(playerPed, false) then
        local vehicle = GetVehiclePedIsIn(playerPed, false)
        local hasUnderglow = false

        -- Check if any underglow is on
        for i = 0, 3 do
            if IsVehicleNeonLightEnabled(vehicle, i) then
                hasUnderglow = true
                break
            end
        end

        -- Toggle underglow
        for i = 0, 3 do
            SetVehicleNeonLightEnabled(vehicle, i, not hasUnderglow)
            if not hasUnderglow then
                SetVehicleNeonLightsColour(vehicle, customColor.r, customColor.g, customColor.b)
            end
        end
    end
end

-- Function to stop RGB mode
local function stopRGBMode()
    rgbActive = false
end

-- Function to start RGB mode
local function toggleRGBMode()
    rgbActive = not rgbActive
    if rgbActive then
        Citizen.CreateThread(function()
            while rgbActive do
                local playerPed = PlayerPedId()
                if IsPedInAnyVehicle(playerPed, false) then
                    local vehicle = GetVehiclePedIsIn(playerPed, false)
                    for i = 0, 3 do
                        SetVehicleNeonLightEnabled(vehicle, i, true)
                    end
                    for r = 0, 255, 5 do
                        SetVehicleNeonLightsColour(vehicle, r, 0, 255 - r)
                        Citizen.Wait(50)
                    end
                    for g = 0, 255, 5 do
                        SetVehicleNeonLightsColour(vehicle, 255 - g, g, 0)
                        Citizen.Wait(50)
                    end
                    for b = 0, 255, 5 do
                        SetVehicleNeonLightsColour(vehicle, 0, 255 - b, b)
                        Citizen.Wait(50)
                    end
                end
            end
        end)
    end
end

-- Create color selection menu
function createColorMenu(menu)
    local submenu = MenuPool:AddSubMenu(menu, "Select Underglow Color")
    for _, color in ipairs(vehicleColors) do
        local item = NativeUI.CreateItem(color.name, "")
        submenu:AddItem(item)
        item.Activated = function(sender, index)
            customColor = color
            stopRGBMode()
            toggleUnderglow()
        end
    end
end

-- Register command to toggle underglow
RegisterCommand("glow", function()
    toggleUnderglow()
end, false)

-- Register command to open color wheel
RegisterCommand("colorwheel", function()
    mainMenu:Visible(not mainMenu:Visible())
end, false)

-- Register command to toggle RGB mode
RegisterCommand("glowrgb", function()
    toggleRGBMode()
end, false)

-- Initialize menu
createColorMenu(mainMenu)
MenuPool:RefreshIndex()

-- Menu processing thread
Citizen.CreateThread(function()
    while true do
        Citizen.Wait(0)
        MenuPool:ProcessMenus()

        -- Prevent the screen from spinning and disable the mouse
        if MenuPool:IsAnyMenuOpen() then
            DisableAllControlActions(0) -- Disable all controls
            EnableControlAction(0, 1, true) -- Enable look left/right
            EnableControlAction(0, 2, true) -- Enable look up/down
            EnableControlAction(0, 142, true) -- Enable melee attack alternate
            EnableControlAction(0, 21, true) -- Enable sprint
            EnableControlAction(0, 24, true) -- Enable attack
            EnableControlAction(0, 25, true) -- Enable aim
            EnableControlAction(0, 47, true) -- Enable weapon
            EnableControlAction(0, 58, true) -- Enable weapon
            EnableControlAction(0, 263, true) -- Enable melee
            EnableControlAction(0, 264, true) -- Enable melee
            EnableControlAction(0, 257, true) -- Enable melee
            EnableControlAction(0, 140, true) -- Enable melee
            EnableControlAction(0, 141, true) -- Enable melee
            EnableControlAction(0, 143, true) -- Enable melee
            EnableControlAction(0, 200, true) -- Enable pause menu
            EnableControlAction(0, 199, true) -- Enable pause menu
            DisableControlAction(0, 199, true) -- Disable pause menu
            EnableControlAction(0, 0, true) -- Enable mouse control
            EnableControlAction(0, 1, true) -- Enable mouse control
            EnableControlAction(0, 2, true) -- Enable mouse control
            EnableControlAction(0, 31, true) -- Enable moving
            EnableControlAction(0, 30, true) -- Enable moving
        end
    end
end)
